==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebActionStripResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActionStripResourceStringsDescription } from "./WebActionStripResourceStringsDescription";
/**
 * @hidden
 */
var WebActionStripResourceStringsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActionStripResourceStringsDescriptionMetadata, _super);
    function WebActionStripResourceStringsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActionStripResourceStringsDescriptionMetadata.b = function (a) {
        if (WebActionStripResourceStringsDescriptionMetadata.a == null) {
            WebActionStripResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActionStripResourceStringsDescriptionMetadata.c(WebActionStripResourceStringsDescriptionMetadata.a);
        }
        if (a.j(WebActionStripResourceStringsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebActionStripResourceStringsDescriptionMetadata.a);
    };
    WebActionStripResourceStringsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActionStripResourceStrings");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Igx_action_strip_button_more_title", "String");
    };
    WebActionStripResourceStringsDescriptionMetadata.d = function (a) {
        WebActionStripResourceStringsDescriptionMetadata.b(a);
        a.aa("WebActionStripResourceStrings", function () { return new WebActionStripResourceStringsDescription(); });
        a.z("WebActionStripResourceStrings", WebActionStripResourceStringsDescriptionMetadata.a);
    };
    WebActionStripResourceStringsDescriptionMetadata.$t = markType(WebActionStripResourceStringsDescriptionMetadata, 'WebActionStripResourceStringsDescriptionMetadata');
    WebActionStripResourceStringsDescriptionMetadata.a = null;
    return WebActionStripResourceStringsDescriptionMetadata;
}(Base));
export { WebActionStripResourceStringsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebActionStripResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActionStripResourceStringsDescription } from "./WebActionStripResourceStringsDescription";
/**
 * @hidden
 */
var WebActionStripResourceStringsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActionStripResourceStringsDescriptionMetadata, _super);
    function WebActionStripResourceStringsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActionStripResourceStringsDescriptionMetadata.b = function (a) {
        if (WebActionStripResourceStringsDescriptionMetadata.a == null) {
            WebActionStripResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActionStripResourceStringsDescriptionMetadata.c(WebActionStripResourceStringsDescriptionMetadata.a);
        }
        if (a.k(WebActionStripResourceStringsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebActionStripResourceStringsDescriptionMetadata.a);
    };
    WebActionStripResourceStringsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActionStripResourceStrings");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Igx_action_strip_button_more_title", "String");
    };
    WebActionStripResourceStringsDescriptionMetadata.d = function (a) {
        WebActionStripResourceStringsDescriptionMetadata.b(a);
        a.ac("WebActionStripResourceStrings", function () { return new WebActionStripResourceStringsDescription(); });
        a.ab("WebActionStripResourceStrings", WebActionStripResourceStringsDescriptionMetadata.a);
    };
    WebActionStripResourceStringsDescriptionMetadata.$t = markType(WebActionStripResourceStringsDescriptionMetadata, 'WebActionStripResourceStringsDescriptionMetadata');
    WebActionStripResourceStringsDescriptionMetadata.a = null;
    return WebActionStripResourceStringsDescriptionMetadata;
}(Base));
export { WebActionStripResourceStringsDescriptionMetadata };
